@@ -1,10 +1,17 @@
 import requests
 import pandas as pd
 import random
-
+import logging
 
 def spider_day(date, question, cookie=None, save_path=None, save_name=None):
 	url = 'http://www.iwencai.com/unifiedwap/unified-wap/v2/result/get-robot-data?source=Ths_iwencai_Xuangu&version=2.0&secondary_intent='
+	logger = logging.getLogger()
+	logger.setLevel(logging.INFO)
+	f = logging.StreamHandler()
+	formatter = logging.Formatter('%(asctime)s - %(filename)s[line:%(lineno)d] - %(levelname)s: %(message)s')
+	f.setLevel(logging.INFO)
+	f.setFormatter(formatter)
+	logger.addHandler(f)
 	if not cookie:
 		cookie = [
 		'cid=b06575e0076839c8c7d1711418d2ab361600616049; ComputerID=b06575e0076839c8c7d1711418d2ab361600616049; WafStatus=0; other_uid=Ths_iwencai_Xuangu_32967b166d370f213dfd24e0ab7371a9; guideState=1; ver_mark=a; user=MDrFr7flRTo6Tm9uZTo1MDA6NDczNDQwNTUyOjcsMTExMTExMTExMTEsNDA7NDQsMTEsNDA7NiwxLDQwOzUsMSw0MDsxLDEwMSw0MDsyLDEsNDA7MywxLDQwOzUsMSw0MDs4LDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAxLDQwOzEwMiwxLDQwOjI0Ojo6NDYzNDQwNTUyOjE2MDQ0NzMyNDU6OjoxNTM3NzA3NjYwOjI2Nzg0MDA6MDoxYmEzZTM5ZTExMTEzOTM5ZmNlNDg4MTk0ZDc2ODZkMDQ6ZGVmYXVsdF80OjE%3D; userid=463440552; u_name=%C5%AF%B7%E5E; escapename=%25u6696%25u5cf0E; ticket=6c7e349b919a23f142195e1aa1486c2a; user_status=0; PHPSESSID=a183c8ebf01efdc4e611389bc2fc871a; v=An5o9WLNrZZQm_myAcrervumz5_Dv0I51IP2HSiH6kG8yxADkE-SSaQTRin7',
@@ -45,12 +52,15 @@ def spider_day(date, question, cookie=None, save_path=None, save_name=None):
 		try:
 			result = response.json()
 		except Exception:
-			raise ValueError('cookie无效')
+			logger.info('cookie无效,{}数据爬取失败'.format(date))
+			raise ValueError('cookie无效,{}数据爬取失败'.format(date))
 	if 'result' in dir():
+		logger.info('爬取{}数据成功'.format(date))
 		temp = result['data']['answer'][0]['txt'][0]['content']['components'][0]['data'][
 			'datas']
 	else:
-		raise ValueError('cookie无效')
+		logger.info('cookie无效,{}数据爬取失败'.format(date))
+		raise ValueError('cookie无效,{}数据爬取失败'.format(date))
 	df_temp = pd.DataFrame(temp)
 	df_temp.dropna(inplace=True)
 	df_temp['date'] = str(date)
@@ -62,8 +72,10 @@ def spider_day(date, question, cookie=None, save_path=None, save_name=None):
 	if save_path:
 		if save_name:
 			df_temp.to_csv(save_path + '/{}.csv'.format(str(date)), index=None)
-			print('保存{}数据成功'.format(date))
+			logger.info('保存{}数据成功'.format(date))
+			# print('保存{}数据成功'.format(date))
 		else:
 			df_temp.to_csv(save_path + '/{}.csv'.format(str(save_name)), index=None)
-			print('保存{}数据成功'.format(date))
+			logger.info('保存{}数据成功'.format(date))
+			# print('保存{}数据成功'.format(date))
 	return df_temp
\ No newline at end of file
